@@ -3,6 +3,9 @@ package main
 import (
 	"errors"
 	"net/http"
+	"time"
+
+	"github.com/shirou/gopsutil/v4/host"
 
 	"github.com/lxc/incus/v6/internal/server/metrics"
 	"github.com/lxc/incus/v6/internal/server/response"
@@ -55,6 +58,8 @@ func metricsGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	out.ProcessesTotal = uint64(osGetProcessesState())
+	out.BootTimeSeconds = uint64(osGetBootTime())
+	out.TimeSeconds = uint64(time.Now().Unix())
 
 	cpuStats, err := osGetCPUMetrics(d)
 	if err != nil {
@@ -88,3 +93,12 @@ func getNetworkMetrics(d *Daemon) ([]metrics.NetworkMetrics, error) {
 
 	return out, nil
 }
+
+func osGetBootTime() int64 {
+	bootTime, err := host.BootTime()
+	if err != nil {
+		return -1
+	}
+
+	return int64(bootTime)
+}
