@@ -3,9 +3,11 @@
 package main
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"io"
+	"net"
 	"os"
 	"os/exec"
 	"runtime"
@@ -13,6 +15,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/FuturFusion/vsock"
 	"github.com/shirou/gopsutil/v4/disk"
 	"golang.org/x/sys/windows"
 	"golang.org/x/sys/windows/registry"
@@ -20,6 +23,7 @@ import (
 	"golang.org/x/sys/windows/svc/debug"
 	"golang.org/x/sys/windows/svc/eventlog"
 
+	"github.com/lxc/incus/v6/internal/ports"
 	"github.com/lxc/incus/v6/internal/server/metrics"
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/api"
@@ -30,8 +34,26 @@ var (
 	// https://dev.to/cosmic_predator/writing-a-windows-service-in-go-1d1m
 	osBaseWorkingDirectory = "C:\\"
 	osAgentConfigPath      = "C:\\Program Files\\Incus-Agent\\incus-agent.yml"
+	osVioSerialPath        = `\\.\org.linuxcontainers.incus`
 )
 
+func osGetListener(port int64) (net.Listener, error) {
+	const CIDAny uint32 = 4294967295 // Equivalent to VMADDR_CID_ANY.
+
+	// Setup the listener on wildcard CID for inbound connections from Incus.
+	// We use the VMADDR_CID_ANY CID so that if the VM's CID changes in the future the listener still works.
+	// A CID change can occur when restoring a stateful VM that was previously using one CID but is
+	// subsequently restored using a different one.
+	l, err := vsock.ListenContextID(CIDAny, ports.HTTPSDefaultPort, nil)
+	if err != nil {
+		return nil, fmt.Errorf("WINDOWS: Failed to listen on vsock: %w", err)
+	}
+
+	logger.Info("Started vsock listener")
+
+	return l, nil
+}
+
 // Start of Windows service code block
 // Inspired of https://github.com/golang/sys/blob/master/windows/svc/example/service.go
 var elog debug.Log
@@ -58,6 +80,14 @@ func (m *incusAgentService) Execute(args []string, r <-chan svc.ChangeRequest, c
 	}
 
 	changes <- svc.Status{State: svc.Running, Accepts: cmdsAccepted}
+
+	ctx, cancelFunc := context.WithCancel(context.Background())
+	defer cancelFunc()
+
+	// Start status notifier in background.
+	cancelStatusNotifier := m.agentCmd.startStatusNotifier(ctx, d.chConnected)
+	defer cancelStatusNotifier()
+
 loop:
 	for {
 		select {
@@ -242,11 +272,38 @@ func osExitStatus(err error) (int, error) {
 func osSetEnv(post *api.InstanceExecPost, env map[string]string) {
 	// SystemRoot is already set by default
 	env["SystemDrive"] = "C:"
+
+	// Program Files directories
+	env["ProgramFiles"] = fmt.Sprintf("%s\\Program Files", env["SystemDrive"])
+	env["ProgramFiles(x86)"] = fmt.Sprintf("%s (x86)", env["ProgramFiles"])
+	env["ProgramW6432"] = fmt.Sprintf("%s", env["ProgramFiles"])
+	env["CommonProgramFiles"] = fmt.Sprintf("%s\\Common Files", env["ProgramFiles"])
+	env["CommonProgramFiles(x86)"] = fmt.Sprintf("%s (x86)\\Common Files", env["ProgramFiles"])
+	env["CommonProgramW6432"] = fmt.Sprintf("%s\\Common Files", env["ProgramFiles"])
+
+	// Windows directories
 	env["WINDIR"] = fmt.Sprintf("%s\\WINDOWS", env["SystemDrive"])
-	system32 := fmt.Sprintf("%s\\System32", env["WINDIR"])
 	env["TMP"] = fmt.Sprintf("%s\\Temp", env["WINDIR"])
 	env["TEMP"] = env["TMP"]
+
+	// System32 directories
+	system32 := fmt.Sprintf("%s\\System32", env["WINDIR"])
+	env["ComSpec"] = fmt.Sprintf("%s\\cmd.exe", system32)
+	env["DriverData"] = fmt.Sprintf("%s\\Drivers\\DriverData", system32)
+
+	// User profile directories
+	env["USERPROFILE"] = fmt.Sprintf("%s\\config\\systemprofile", system32)
+	env["LOCALAPPDATA"] = fmt.Sprintf("%s\\AppData\\Local", env["USERPROFILE"])
+	env["APPDATA"] = fmt.Sprintf("%s\\AppData\\Roaming", env["USERPROFILE"])
+
+	// Miscellaneous
+	env["COMPUTERNAME"] = ""
 	env["PATH"] = fmt.Sprintf("%s;%s;%s\\WindowsPowerShell\\v1.0", system32, env["WINDIR"], system32)
+	env["PATHEXT"] = "COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.CPL"
+
+	env["ProgramData"] = fmt.Sprintf("%s\\ProgramData", env["SystemDrive"])
+	env["ALLUSERSPROFILE"] = env["ProgramData"]
+	env["PUBLIC"] = fmt.Sprintf("%s\\Users\\Public", env["SystemDrive"])
 
 	// Set the default working directory.
 	if post.Cwd == "" {
