@@ -5,6 +5,9 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io"
+	"net/http"
+	"net/url"
 	"os"
 	"os/exec"
 	"os/signal"
@@ -48,50 +51,50 @@ type Migration struct {
 }
 
 func (m *Migration) runMigration(migrationHandler func(path string) error) error {
-	m.mounts = append(m.mounts, m.sourcePath)
-
-	// Get and sort the mounts
-	sort.Strings(m.mounts)
-
-	// Create the mount namespace and ensure we're not moved around
-	runtime.LockOSThread()
-	defer runtime.UnlockOSThread()
-
-	// Unshare a new mntns so our mounts don't leak
-	err := unix.Unshare(unix.CLONE_NEWNS)
-	if err != nil {
-		return fmt.Errorf("Failed to unshare mount namespace: %w", err)
-	}
-
-	// Prevent mount propagation back to initial namespace
-	err = unix.Mount("", "/", "", unix.MS_REC|unix.MS_PRIVATE, "")
-	if err != nil {
-		return fmt.Errorf("Failed to disable mount propagation: %w", err)
-	}
-
 	// Create the temporary directory to be used for the mounts
 	path, err := os.MkdirTemp("", "incus-migrate_mount_")
 	if err != nil {
 		return err
 	}
 
-	// Automatically clean-up the temporary path on exit
-	defer func(path string) {
-		// Unmount the path if it's a mountpoint.
-		_ = unix.Unmount(path, unix.MNT_DETACH)
-		_ = unix.Unmount(filepath.Join(path, "root.img"), unix.MNT_DETACH)
-
-		// Cleanup VM image files.
-		_ = os.Remove(filepath.Join(path, "converted-raw-image.img"))
-		_ = os.Remove(filepath.Join(path, "root.img"))
-
-		// Remove the directory itself.
-		_ = os.Remove(path)
-	}(path)
-
 	var fullPath string
 
 	if m.migrationType == MigrationTypeContainer || m.migrationType == MigrationTypeVolumeFilesystem {
+		m.mounts = append(m.mounts, m.sourcePath)
+
+		// Get and sort the mounts.
+		sort.Strings(m.mounts)
+
+		// Ensure we're not moved around.
+		runtime.LockOSThread()
+		defer runtime.UnlockOSThread()
+
+		// Unshare a new mntns so our mounts don't leak.
+		err := unix.Unshare(unix.CLONE_NEWNS)
+		if err != nil {
+			return fmt.Errorf("Failed to unshare mount namespace: %w", err)
+		}
+
+		// Prevent mount propagation back to initial namespace
+		err = unix.Mount("", "/", "", unix.MS_REC|unix.MS_PRIVATE, "")
+		if err != nil {
+			return fmt.Errorf("Failed to disable mount propagation: %w", err)
+		}
+
+		// Automatically clean-up the temporary path on exit
+		defer func(path string) {
+			// Unmount the path if it's a mountpoint.
+			_ = unix.Unmount(path, unix.MNT_DETACH)
+			_ = unix.Unmount(filepath.Join(path, "root.img"), unix.MNT_DETACH)
+
+			// Cleanup VM image files.
+			_ = os.Remove(filepath.Join(path, "converted-raw-image.img"))
+			_ = os.Remove(filepath.Join(path, "root.img"))
+
+			// Remove the directory itself.
+			_ = os.Remove(path)
+		}(path)
+
 		// Create the rootfs directory
 		fullPath = fmt.Sprintf("%s/rootfs", path)
 
@@ -149,25 +152,12 @@ func (m *Migration) runMigration(migrationHandler func(path string) error) error
 			m.sourcePath = destImg
 		}
 
+		err = os.Symlink(m.sourcePath, filepath.Join(path, "root.img"))
+		if err != nil {
+			return err
+		}
+
 		fullPath = path
-		target := filepath.Join(path, "root.img")
-
-		err = os.WriteFile(target, nil, 0o644)
-		if err != nil {
-			return fmt.Errorf("Failed to create %q: %w", target, err)
-		}
-
-		// Mount the path
-		err = unix.Mount(m.sourcePath, target, "none", unix.MS_BIND, "")
-		if err != nil {
-			return fmt.Errorf("Failed to mount %s: %w", m.sourcePath, err)
-		}
-
-		// Make it read-only
-		err = unix.Mount("", target, "none", unix.MS_BIND|unix.MS_RDONLY|unix.MS_REMOUNT, "")
-		if err != nil {
-			return fmt.Errorf("Failed to make %s read-only: %w", m.sourcePath, err)
-		}
 	}
 
 	return migrationHandler(fullPath)
@@ -227,12 +217,24 @@ func (m *Migration) askTarget() error {
 func (m *Migration) askSourcePath(question string) error {
 	var err error
 
+	var isURL bool
 	m.sourcePath, err = m.asker.AskString(question, "", func(s string) error {
+		// Allow URLs.
+		isURL = false
+
+		u, err := url.Parse(s)
+		if err == nil && u.Scheme != "" && u.Host != "" {
+			isURL = true
+
+			return nil
+		}
+
+		// Check if a valid path.
 		if !util.PathExists(s) {
 			return errors.New("Path does not exist")
 		}
 
-		_, err := os.Stat(s)
+		_, err = os.Stat(s)
 		if err != nil {
 			return err
 		}
@@ -243,6 +245,43 @@ func (m *Migration) askSourcePath(question string) error {
 		return err
 	}
 
+	// If a URL, download it.
+	if isURL {
+		// Create a temporary file.
+		f, err := os.CreateTemp("", "")
+		if err != nil {
+			return err
+		}
+
+		defer func() { _ = f.Close() }()
+
+		// Download the target.
+		resp, err := http.Get(m.sourcePath)
+		if err != nil {
+			return err
+		}
+
+		defer resp.Body.Close()
+
+		fmt.Printf("Downloading %q\n", m.sourcePath)
+
+		for {
+			// Read 4MB at a time.
+			_, err = io.CopyN(f, resp.Body, 4*1024*1024)
+			if err != nil {
+				if err == io.EOF {
+					break
+				}
+
+				_ = os.Remove(f.Name())
+
+				return err
+			}
+		}
+
+		m.sourcePath = f.Name()
+	}
+
 	return nil
 }
 
@@ -451,16 +490,6 @@ func (c *cmdMigrate) askServer() (incus.InstanceServer, string, error) {
 }
 
 func (c *cmdMigrate) run(_ *cobra.Command, _ []string) error {
-	// Quick checks.
-	if os.Geteuid() != 0 {
-		return errors.New("This tool must be run as root")
-	}
-
-	_, err := exec.LookPath("rsync")
-	if err != nil {
-		return errors.New("Unable to find required command \"rsync\"")
-	}
-
 	// Server
 	server, clientFingerprint, err := c.askServer()
 	if err != nil {
