@@ -7,8 +7,9 @@ import (
 
 	"github.com/spf13/cobra"
 
-	cli "github.com/lxc/incus/v6/internal/cmd"
+	u "github.com/lxc/incus/v6/cmd/incus/usage"
 	"github.com/lxc/incus/v6/internal/i18n"
+	cli "github.com/lxc/incus/v6/shared/cmd"
 )
 
 type cmdAlias struct {
@@ -19,7 +20,7 @@ type cmdAlias struct {
 // This includes commands for adding, listing, renaming, and removing aliases, along with their usage and descriptions.
 func (c *cmdAlias) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("alias")
+	cmd.Use = cli.U("alias")
 	cmd.Short = i18n.G("Manage command aliases")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Manage command aliases`))
@@ -57,7 +58,7 @@ type cmdAliasAdd struct {
 // It specifies the command usage, description, and examples, and links it to the RunE method for execution logic.
 func (c *cmdAliasAdd) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("add", i18n.G("<alias> <target>"))
+	cmd.Use = cli.U("add", u.NewName(u.Alias), u.Target(u.Placeholder(i18n.G("command"))))
 	cmd.Aliases = []string{"create"}
 	cmd.Short = i18n.G("Add new aliases")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -107,7 +108,7 @@ type cmdAliasList struct {
 // It specifies the command usage, description, aliases, and output formatting options, and links it to the RunE method for execution logic.
 func (c *cmdAliasList) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("list")
+	cmd.Use = cli.U("list")
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List aliases")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -168,7 +169,7 @@ type cmdAliasRename struct {
 // This command allows a user to rename existing aliases in the CLI application.
 func (c *cmdAliasRename) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("rename", i18n.G("<old alias> <new alias>"))
+	cmd.Use = cli.U("rename", u.Alias, u.NewName(u.Alias))
 	cmd.Aliases = []string{"mv"}
 	cmd.Short = i18n.G("Rename aliases")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -223,7 +224,7 @@ type cmdAliasRemove struct {
 // This command enables the removal of a given alias from the command line interface.
 func (c *cmdAliasRemove) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("remove", i18n.G("<alias>"))
+	cmd.Use = cli.U("remove", u.Alias)
 	cmd.Aliases = []string{"delete", "rm"}
 	cmd.Short = i18n.G("Remove aliases")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
