@@ -4,6 +4,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"maps"
 	"os"
 	"slices"
 	"sort"
@@ -12,9 +13,10 @@ import (
 	"github.com/spf13/cobra"
 	yaml "gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/v6/internal/cmd"
+	u "github.com/lxc/incus/v6/cmd/incus/usage"
 	"github.com/lxc/incus/v6/internal/i18n"
 	"github.com/lxc/incus/v6/shared/api"
+	cli "github.com/lxc/incus/v6/shared/cmd"
 	"github.com/lxc/incus/v6/shared/termios"
 )
 
@@ -31,7 +33,7 @@ type clusterGroupColumn struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroup) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("group")
+	cmd.Use = cli.U("group")
 	cmd.Short = i18n.G("Manage cluster groups")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Manage cluster groups`))
@@ -64,6 +66,18 @@ func (c *cmdClusterGroup) Command() *cobra.Command {
 	clusterGroupRenameCmd := cmdClusterGroupRename{global: c.global, cluster: c.cluster}
 	cmd.AddCommand(clusterGroupRenameCmd.Command())
 
+	// Get
+	clusterGroupGetCmd := cmdClusterGroupGet{global: c.global, cluster: c.cluster}
+	cmd.AddCommand(clusterGroupGetCmd.Command())
+
+	// Set
+	clusterGroupSetCmd := cmdClusterGroupSet{global: c.global, cluster: c.cluster}
+	cmd.AddCommand(clusterGroupSetCmd.Command())
+
+	// Unset
+	clusterGroupUnsetCmd := cmdClusterGroupUnset{global: c.global, cluster: c.cluster, clusterSet: &clusterGroupSetCmd}
+	cmd.AddCommand(clusterGroupUnsetCmd.Command())
+
 	// Show
 	clusterGroupShowCmd := cmdClusterGroupShow{global: c.global, cluster: c.cluster}
 	cmd.AddCommand(clusterGroupShowCmd.Command())
@@ -84,7 +98,7 @@ type cmdClusterGroupAssign struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupAssign) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("assign", i18n.G("[<remote>:]<member> <group>"))
+	cmd.Use = cli.U("assign", u.Member.Remote(), u.Group)
 	cmd.Aliases = []string{"apply"}
 	cmd.Short = i18n.G("Assign sets of groups to cluster members")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -172,7 +186,7 @@ type cmdClusterGroupCreate struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupCreate) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("create", i18n.G("[<remote>:]<group>"))
+	cmd.Use = cli.U("create", u.NewName(u.Group).Remote())
 	cmd.Short = i18n.G("Create a cluster group")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Create a cluster group`))
@@ -263,20 +277,16 @@ type cmdClusterGroupDelete struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupDelete) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("delete", i18n.G("[<remote>:]<group>"))
+	cmd.Use = cli.U("delete", u.Group.Remote().List(1))
 	cmd.Aliases = []string{"rm"}
-	cmd.Short = i18n.G("Delete a cluster group")
+	cmd.Short = i18n.G("Delete cluster groups")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
-		`Delete a cluster group`))
+		`Delete cluster groups`))
 
 	cmd.RunE = c.Run
 
-	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
-		if len(args) == 0 {
-			return c.global.cmpClusterGroups(toComplete)
-		}
-
-		return nil, cobra.ShellCompDirectiveNoFileComp
+	cmd.ValidArgsFunction = func(_ *cobra.Command, _ []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		return c.global.cmpClusterGroups(toComplete)
 	}
 
 	return cmd
@@ -285,31 +295,31 @@ func (c *cmdClusterGroupDelete) Command() *cobra.Command {
 // Run runs the actual command logic.
 func (c *cmdClusterGroupDelete) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
-	exit, err := c.global.checkArgs(cmd, args, 1, 1)
+	exit, err := c.global.checkArgs(cmd, args, 1, -1)
 	if exit {
 		return err
 	}
 
 	// Parse remote
-	resources, err := c.global.parseServers(args[0])
+	resources, err := c.global.parseServers(args...)
 	if err != nil {
 		return err
 	}
 
-	resource := resources[0]
+	for _, resource := range resources {
+		if resource.name == "" {
+			return errors.New(i18n.G("Missing cluster group name"))
+		}
 
-	if resource.name == "" {
-		return errors.New(i18n.G("Missing cluster group name"))
-	}
+		// Delete the cluster group
+		err = resource.server.DeleteClusterGroup(resource.name)
+		if err != nil {
+			return err
+		}
 
-	// Delete the cluster group
-	err = resource.server.DeleteClusterGroup(resource.name)
-	if err != nil {
-		return err
-	}
-
-	if !c.global.flagQuiet {
-		fmt.Printf(i18n.G("Cluster group %s deleted")+"\n", resource.name)
+		if !c.global.flagQuiet {
+			fmt.Printf(i18n.G("Cluster group %s deleted")+"\n", resource.name)
+		}
 	}
 
 	return nil
@@ -324,7 +334,7 @@ type cmdClusterGroupEdit struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupEdit) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("edit", i18n.G("[<remote>:]<group>"))
+	cmd.Use = cli.U("edit", u.Group.Remote())
 	cmd.Short = i18n.G("Edit a cluster group")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Edit a cluster group`))
@@ -391,7 +401,7 @@ func (c *cmdClusterGroupEdit) Run(cmd *cobra.Command, args []string) error {
 	}
 
 	// Spawn the editor
-	content, err := textEditor("", []byte(c.helpTemplate()+"\n\n"+string(data)))
+	content, err := cli.TextEditor("", []byte(c.helpTemplate()+"\n\n"+string(data)))
 	if err != nil {
 		return err
 	}
@@ -415,7 +425,7 @@ func (c *cmdClusterGroupEdit) Run(cmd *cobra.Command, args []string) error {
 				return err
 			}
 
-			content, err = textEditor("", content)
+			content, err = cli.TextEditor("", content)
 			if err != nil {
 				return err
 			}
@@ -448,7 +458,7 @@ type cmdClusterGroupList struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupList) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("list", i18n.G("[<remote>:]"))
+	cmd.Use = cli.U("list", u.RemoteColonOpt)
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List all the cluster groups")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -605,7 +615,7 @@ type cmdClusterGroupRemove struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupRemove) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("remove", i18n.G("[<remote>:]<member> <group>"))
+	cmd.Use = cli.U("remove", u.Member.Remote(), u.Group)
 	cmd.Short = i18n.G("Remove member from group")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Remove a cluster member from a cluster group`))
@@ -689,7 +699,7 @@ type cmdClusterGroupRename struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupRename) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("rename", i18n.G("[<remote>:]<group> <new-name>"))
+	cmd.Use = cli.U("rename", u.Group.Remote(), u.NewName(u.Group))
 	cmd.Aliases = []string{"mv"}
 	cmd.Short = i18n.G("Rename a cluster group")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
@@ -746,7 +756,7 @@ type cmdClusterGroupShow struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupShow) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("show", i18n.G("[<remote>:]<group>"))
+	cmd.Use = cli.U("show", u.Group.Remote())
 	cmd.Short = i18n.G("Show cluster group configurations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Show cluster group configurations`))
@@ -809,7 +819,7 @@ type cmdClusterGroupAdd struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdClusterGroupAdd) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = usage("add", i18n.G("[<remote>:]<member> <group>"))
+	cmd.Use = cli.U("add", u.Member.Remote(), u.Group)
 	cmd.Short = i18n.G("Add member to group")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Add a cluster member to a cluster group`))
@@ -874,3 +884,205 @@ func (c *cmdClusterGroupAdd) Run(cmd *cobra.Command, args []string) error {
 
 	return nil
 }
+
+// Get.
+type cmdClusterGroupGet struct {
+	global  *cmdGlobal
+	cluster *cmdCluster
+
+	flagIsProperty bool
+}
+
+// Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
+func (c *cmdClusterGroupGet) Command() *cobra.Command {
+	cmd := &cobra.Command{}
+	cmd.Use = cli.U("get", u.Group.Remote(), u.Key)
+	cmd.Short = i18n.G("Get values for cluster group configuration keys")
+	cmd.Long = cli.FormatSection(i18n.G("Description"), cmd.Short)
+
+	cmd.Flags().BoolVarP(&c.flagIsProperty, "property", "p", false, i18n.G("Get the key as a cluster group property"))
+	cmd.RunE = c.Run
+
+	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		if len(args) == 0 {
+			return c.global.cmpClusterGroups(toComplete)
+		}
+
+		if len(args) == 1 {
+			return c.global.cmpClusterGroupConfigs(args[0])
+		}
+
+		return nil, cobra.ShellCompDirectiveNoFileComp
+	}
+
+	return cmd
+}
+
+// Run runs the actual command logic.
+func (c *cmdClusterGroupGet) Run(cmd *cobra.Command, args []string) error {
+	// Quick checks.
+	exit, err := c.global.checkArgs(cmd, args, 2, 2)
+	if exit {
+		return err
+	}
+
+	// Parse remote
+	resources, err := c.global.parseServers(args[0])
+	if err != nil {
+		return err
+	}
+
+	resource := resources[0]
+
+	// Get the group information
+	group, _, err := resource.server.GetClusterGroup(resource.name)
+	if err != nil {
+		return err
+	}
+
+	if c.flagIsProperty {
+		w := group.Writable()
+		res, err := getFieldByJSONTag(&w, args[1])
+		if err != nil {
+			return fmt.Errorf(i18n.G("The property %q does not exist on the cluster group %q: %v"), args[1], resource.name, err)
+		}
+
+		fmt.Printf("%v\n", res)
+		return nil
+	}
+
+	value, ok := group.Config[args[1]]
+	if !ok {
+		return fmt.Errorf(i18n.G("The key %q does not exist on cluster group %q"), args[1], resource.name)
+	}
+
+	fmt.Printf("%s\n", value)
+	return nil
+}
+
+// Set.
+type cmdClusterGroupSet struct {
+	global  *cmdGlobal
+	cluster *cmdCluster
+
+	flagIsProperty bool
+}
+
+// Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
+func (c *cmdClusterGroupSet) Command() *cobra.Command {
+	cmd := &cobra.Command{}
+	cmd.Use = cli.U("set", u.Group.Remote(), u.KV.List(1))
+	cmd.Short = i18n.G("Set a cluster group's configuration keys")
+	cmd.Long = cli.FormatSection(i18n.G("Description"), cmd.Short)
+
+	cmd.Flags().BoolVarP(&c.flagIsProperty, "property", "p", false, i18n.G("Set the key as a cluster group property"))
+	cmd.RunE = c.Run
+
+	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		if len(args) == 0 {
+			return c.global.cmpClusterGroups(toComplete)
+		}
+
+		return nil, cobra.ShellCompDirectiveNoFileComp
+	}
+
+	return cmd
+}
+
+// Run runs the actual command logic.
+func (c *cmdClusterGroupSet) Run(cmd *cobra.Command, args []string) error {
+	// Quick checks.
+	exit, err := c.global.checkArgs(cmd, args, 2, -1)
+	if exit {
+		return err
+	}
+
+	// Parse remote
+	resources, err := c.global.parseServers(args[0])
+	if err != nil {
+		return err
+	}
+
+	resource := resources[0]
+
+	// Get the group information
+	group, _, err := resource.server.GetClusterGroup(resource.name)
+	if err != nil {
+		return err
+	}
+
+	// Get the new config keys
+	keys, err := getConfig(args[1:]...)
+	if err != nil {
+		return err
+	}
+
+	writable := group.Writable()
+	if c.flagIsProperty {
+		if cmd.Name() == "unset" {
+			for k := range keys {
+				err := unsetFieldByJSONTag(&writable, k)
+				if err != nil {
+					return fmt.Errorf(i18n.G("Error unsetting property: %v"), err)
+				}
+			}
+		} else {
+			err := unpackKVToWritable(&writable, keys)
+			if err != nil {
+				return fmt.Errorf(i18n.G("Error setting properties: %v"), err)
+			}
+		}
+	} else {
+		maps.Copy(writable.Config, keys)
+	}
+
+	return resource.server.UpdateClusterGroup(resource.name, writable, "")
+}
+
+// Unset.
+type cmdClusterGroupUnset struct {
+	global     *cmdGlobal
+	cluster    *cmdCluster
+	clusterSet *cmdClusterGroupSet
+
+	flagIsProperty bool
+}
+
+// Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
+func (c *cmdClusterGroupUnset) Command() *cobra.Command {
+	cmd := &cobra.Command{}
+	cmd.Use = cli.U("unset", u.Group.Remote(), u.Key)
+	cmd.Short = i18n.G("Unset a cluster group's configuration keys")
+	cmd.Long = cli.FormatSection(i18n.G("Description"), cmd.Short)
+
+	cmd.Flags().BoolVarP(&c.flagIsProperty, "property", "p", false, i18n.G("Unset the key as a cluster group property"))
+	cmd.RunE = c.Run
+
+	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		if len(args) == 0 {
+			return c.global.cmpClusterGroups(toComplete)
+		}
+
+		if len(args) == 1 {
+			return c.global.cmpClusterGroupConfigs(args[0])
+		}
+
+		return nil, cobra.ShellCompDirectiveNoFileComp
+	}
+
+	return cmd
+}
+
+// Run runs the actual command logic.
+func (c *cmdClusterGroupUnset) Run(cmd *cobra.Command, args []string) error {
+	// Quick checks.
+	exit, err := c.global.checkArgs(cmd, args, 2, 2)
+	if exit {
+		return err
+	}
+
+	c.clusterSet.flagIsProperty = c.flagIsProperty
+
+	args = append(args, "")
+	return c.clusterSet.Run(cmd, args)
+}
