@@ -624,19 +624,26 @@ func doApi10Update(d *Daemon, r *http.Request, req api.ServerPut, patch bool) re
 
 		// Validate the storage volumes
 		if nodeValues["storage.backups_volume"] != "" && nodeValues["storage.backups_volume"] != newNodeConfig.StorageBackupsVolume() {
-			err := daemonStorageValidate(s, nodeValues["storage.backups_volume"])
+			err := daemonStorageValidate(s, "backups", nodeValues["storage.backups_volume"])
 			if err != nil {
 				return fmt.Errorf("Failed validation of %q: %w", "storage.backups_volume", err)
 			}
 		}
 
 		if nodeValues["storage.images_volume"] != "" && nodeValues["storage.images_volume"] != newNodeConfig.StorageImagesVolume() {
-			err := daemonStorageValidate(s, nodeValues["storage.images_volume"])
+			err := daemonStorageValidate(s, "images", nodeValues["storage.images_volume"])
 			if err != nil {
 				return fmt.Errorf("Failed validation of %q: %w", "storage.images_volume", err)
 			}
 		}
 
+		if nodeValues["storage.logs_volume"] != "" && nodeValues["storage.logs_volume"] != newNodeConfig.StorageLogsVolume() {
+			err := daemonStorageValidate(s, "logs", nodeValues["storage.logs_volume"])
+			if err != nil {
+				return fmt.Errorf("Failed validation of %q: %w", "storage.logs_volume", err)
+			}
+		}
+
 		if patch {
 			nodeChanged, err = newNodeConfig.Patch(nodeValues)
 		} else {
@@ -951,6 +958,14 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 		}
 	}
 
+	value, ok = nodeChanged["storage.logs_volume"]
+	if ok {
+		err := daemonStorageMove(s, "logs", value)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Apply larger changes.
 	if acmeChanged {
 		err := autoRenewCertificate(s.ShutdownCtx, d, true)
