@@ -1,6 +1,7 @@
 package main
 
 import (
+	"errors"
 	"fmt"
 	"net/http"
 	"net/url"
@@ -15,11 +16,9 @@ import (
 	"github.com/lxc/incus/v6/internal/server/auth"
 	"github.com/lxc/incus/v6/internal/server/instance"
 	"github.com/lxc/incus/v6/internal/server/lifecycle"
-	"github.com/lxc/incus/v6/internal/server/project"
 	"github.com/lxc/incus/v6/internal/server/request"
 	"github.com/lxc/incus/v6/internal/server/response"
 	"github.com/lxc/incus/v6/internal/server/storage"
-	internalUtil "github.com/lxc/incus/v6/internal/util"
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/revert"
 )
@@ -104,18 +103,7 @@ var instanceExecOutputsCmd = APIEndpoint{
 //	  "500":
 //	    $ref: "#/responses/InternalServerError"
 func instanceLogsGet(d *Daemon, r *http.Request) response.Response {
-	/* Let's explicitly *not* try to do a containerLoadByName here. In some
-	 * cases (e.g. when container creation failed), the container won't
-	 * exist in the DB but it does have some log files on disk.
-	 *
-	 * However, we should check this name and ensure it's a valid container
-	 * name just so that people can't list arbitrary directories.
-	 */
-
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
+	s := d.State()
 
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
@@ -124,11 +112,17 @@ func instanceLogsGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
+	}
+
+	// Ensure instance exists.
+	inst, err := instance.LoadByProjectAndName(s, projectName, name)
+	if err != nil {
+		return response.SmartError(err)
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(d.State(), r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(d.State(), r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -137,15 +131,9 @@ func instanceLogsGet(d *Daemon, r *http.Request) response.Response {
 		return resp
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	result := []string{}
 
-	fullName := project.Instance(projectName, name)
-	dents, err := os.ReadDir(internalUtil.LogPath(fullName))
+	dents, err := os.ReadDir(inst.LogPath())
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -196,11 +184,6 @@ func instanceLogsGet(d *Daemon, r *http.Request) response.Response {
 func instanceLogGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
 	if err != nil {
@@ -208,7 +191,7 @@ func instanceLogGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	// Ensure instance exists.
@@ -218,7 +201,7 @@ func instanceLogGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -232,17 +215,12 @@ func instanceLogGet(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	if !validLogFileName(file) {
 		return response.BadRequest(fmt.Errorf("Log file name %q not valid", file))
 	}
 
 	ent := response.FileResponseEntry{
-		Path:     internalUtil.LogPath(project.Instance(projectName, name), file),
+		Path:     filepath.Join(inst.LogPath(), file),
 		Filename: file,
 	}
 
@@ -280,11 +258,6 @@ func instanceLogGet(d *Daemon, r *http.Request) response.Response {
 func instanceLogDelete(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
 	if err != nil {
@@ -292,7 +265,7 @@ func instanceLogDelete(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	// Ensure instance exists.
@@ -302,7 +275,7 @@ func instanceLogDelete(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -316,20 +289,15 @@ func instanceLogDelete(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	if !validLogFileName(file) {
 		return response.BadRequest(fmt.Errorf("Log file name %q not valid", file))
 	}
 
 	if !strings.HasSuffix(file, ".log") || file == "lxc.log" || file == "qemu.log" {
-		return response.BadRequest(fmt.Errorf("Only log files excluding qemu.log and lxc.log may be deleted"))
+		return response.BadRequest(errors.New("Only log files excluding qemu.log and lxc.log may be deleted"))
 	}
 
-	err = os.Remove(internalUtil.LogPath(project.Instance(projectName, name), file))
+	err = os.Remove(filepath.Join(inst.LogPath(), file))
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -392,11 +360,6 @@ func instanceLogDelete(d *Daemon, r *http.Request) response.Response {
 func instanceExecOutputsGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
 	if err != nil {
@@ -404,7 +367,7 @@ func instanceExecOutputsGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	// Ensure instance exists.
@@ -414,7 +377,7 @@ func instanceExecOutputsGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(d.State(), r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(d.State(), r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -423,11 +386,6 @@ func instanceExecOutputsGet(d *Daemon, r *http.Request) response.Response {
 		return resp
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	// Mount the instance's root volume
 	pool, err := storage.LoadByInstance(s, inst)
 	if err != nil {
@@ -492,16 +450,11 @@ func instanceExecOutputsGet(d *Daemon, r *http.Request) response.Response {
 //	  "500":
 //	    $ref: "#/responses/InternalServerError"
 func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	s := d.State()
 
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
 	if err != nil {
@@ -509,7 +462,7 @@ func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	// Ensure instance exists.
@@ -519,7 +472,7 @@ func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -533,11 +486,6 @@ func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	if !validExecOutputFileName(file) {
 		return response.BadRequest(fmt.Errorf("Exec record-output file name %q not valid", file))
 	}
@@ -553,9 +501,9 @@ func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	revert.Add(func() { _ = pool.UnmountInstance(inst, nil) })
-	cleanup := revert.Clone()
-	revert.Success()
+	reverter.Add(func() { _ = pool.UnmountInstance(inst, nil) })
+	cleanup := reverter.Clone()
+	reverter.Success()
 
 	ent := response.FileResponseEntry{
 		Path:     filepath.Join(inst.ExecOutputPath(), file),
@@ -597,11 +545,6 @@ func instanceExecOutputGet(d *Daemon, r *http.Request) response.Response {
 func instanceExecOutputDelete(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
 
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	name, err := url.PathUnescape(mux.Vars(r)["name"])
 	if err != nil {
@@ -609,7 +552,7 @@ func instanceExecOutputDelete(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	// Ensure instance exists.
@@ -619,7 +562,7 @@ func instanceExecOutputDelete(d *Daemon, r *http.Request) response.Response {
 	}
 
 	// Handle requests targeted to a container on a different node
-	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name, instanceType)
+	resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name)
 	if err != nil {
 		return response.SmartError(err)
 	}
@@ -633,11 +576,6 @@ func instanceExecOutputDelete(d *Daemon, r *http.Request) response.Response {
 		return response.SmartError(err)
 	}
 
-	err = instance.ValidName(name, false)
-	if err != nil {
-		return response.BadRequest(err)
-	}
-
 	if !validExecOutputFileName(file) {
 		return response.BadRequest(fmt.Errorf("Exec record-output file name %q not valid", file))
 	}
@@ -666,6 +604,11 @@ func instanceExecOutputDelete(d *Daemon, r *http.Request) response.Response {
 }
 
 func validLogFileName(fname string) bool {
+	// Make sure that there's nothing fishy about the provided file name.
+	if filepath.Base(fname) != fname {
+		return false
+	}
+
 	/* Let's just require that the paths be relative, so that we don't have
 	 * to deal with any escaping or whatever.
 	 */
