@@ -3,9 +3,12 @@ package main
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
+	"maps"
 	"net/http"
 	"net/url"
+	"slices"
 	"strings"
 
 	"github.com/gorilla/mux"
@@ -32,6 +35,7 @@ import (
 	"github.com/lxc/incus/v6/shared/api"
 	apiScriptlet "github.com/lxc/incus/v6/shared/api/scriptlet"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // swagger:operation POST /1.0/instances/{name} instances instance_post
@@ -78,11 +82,6 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 	<-d.waitReady.Done()
 
 	// Parse the request URL.
-	instanceType, err := urlInstanceTypeDetect(r)
-	if err != nil {
-		return response.SmartError(err)
-	}
-
 	projectName := request.ProjectParam(r)
 	target := request.QueryParam(r, "target")
 
@@ -93,18 +92,18 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 
 	// Quick checks.
 	if internalInstance.IsSnapshot(name) {
-		return response.BadRequest(fmt.Errorf("Invalid instance name"))
+		return response.BadRequest(errors.New("Invalid instance name"))
 	}
 
 	if target != "" && !s.ServerClustered {
-		return response.BadRequest(fmt.Errorf("Target only allowed when clustered"))
+		return response.BadRequest(errors.New("Target only allowed when clustered"))
 	}
 
 	// Check if the server the instance is running on is currently online.
 	var sourceMemberInfo *db.NodeInfo
 	err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 		// Load source node.
-		sourceAddress, err := tx.GetNodeAddressOfInstance(ctx, projectName, name, instanceType)
+		sourceAddress, err := tx.GetNodeAddressOfInstance(ctx, projectName, name)
 		if err != nil {
 			return fmt.Errorf("Failed to get address of instance's member: %w", err)
 		}
@@ -129,7 +128,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 
 	// More checks.
 	if target == "" && sourceMemberInfo != nil && sourceMemberInfo.IsOffline(s.GlobalConfig.OfflineThreshold()) {
-		return response.BadRequest(fmt.Errorf("Can't perform action as server is currently offline"))
+		return response.BadRequest(errors.New("Can't perform action as server is currently offline"))
 	}
 
 	// Handle request forwarding.
@@ -141,7 +140,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 		}
 	} else if target == "" || sourceMemberInfo == nil || !sourceMemberInfo.IsOffline(s.GlobalConfig.OfflineThreshold()) {
 		// Forward the request to the instance's current location (if not local).
-		resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name, instanceType)
+		resp, err := forwardedResponseIfInstanceIsRemote(s, r, projectName, name)
 		if err != nil {
 			return response.SmartError(err)
 		}
@@ -225,7 +224,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 
 	// Start handling migrations.
 	if inst.IsSnapshot() {
-		return response.BadRequest(fmt.Errorf("Instance snapshots cannot be moved on their own"))
+		return response.BadRequest(errors.New("Instance snapshots cannot be moved on their own"))
 	}
 
 	// Checks for running instances.
@@ -233,28 +232,32 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 		if req.Pool != "" || req.Project != "" || target != "" {
 			// Stateless migrations need the instance stopped.
 			if !req.Live {
-				return response.BadRequest(fmt.Errorf("Instance must be stopped to be moved statelessly"))
+				return response.BadRequest(errors.New("Instance must be stopped to be moved statelessly"))
 			}
 
 			// Storage pool changes require a target flag.
 			if req.Pool != "" {
 				if inst.Type() != instancetype.VM {
-					return response.BadRequest(fmt.Errorf("Storage pool change supported only by virtual-machines"))
+					return response.BadRequest(errors.New("Live storage pool changes aren't supported for containers"))
+				}
+
+				if !s.ServerClustered {
+					return response.BadRequest(errors.New("Live storage pool changes aren't supported on standalone systems"))
 				}
 
 				if target == "" {
-					return response.BadRequest(fmt.Errorf("Storage pool can be specified only together with target flag"))
+					return response.BadRequest(errors.New("Live storage pool changes require the VM be moved to another cluster member"))
 				}
 			}
 
 			// Project changes require a stopped instance.
 			if req.Project != "" {
-				return response.BadRequest(fmt.Errorf("Instance must be stopped to be moved across projects"))
+				return response.BadRequest(errors.New("Instance must be stopped to be moved across projects"))
 			}
 
 			// Name changes require a stopped instance.
 			if req.Name != "" {
-				return response.BadRequest(fmt.Errorf("Instance must be stopped to change their names"))
+				return response.BadRequest(errors.New("Instance must be stopped to change their names"))
 			}
 		}
 	} else {
@@ -264,7 +267,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 
 	// Check for offline sources.
 	if sourceMemberInfo != nil && sourceMemberInfo.IsOffline(s.GlobalConfig.OfflineThreshold()) && (req.Pool != "" || req.Project != "" || req.Name != "") {
-		return response.BadRequest(fmt.Errorf("Instance server is currently offline"))
+		return response.BadRequest(errors.New("Instance server is currently offline"))
 	}
 
 	// When in a cluster, default to keeping current location.
@@ -398,7 +401,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 			req := apiScriptlet.InstancePlacement{
 				InstancesPost: api.InstancesPost{
 					Name: name,
-					Type: api.InstanceType(instanceType.String()),
+					Type: api.InstanceTypeAny,
 					InstancePut: api.InstancePut{
 						Config:   db.ExpandInstanceConfig(inst.LocalConfig(), profiles),
 						Devices:  db.ExpandInstanceDevices(deviceConfig.NewDevices(inst.LocalDevices().CloneNative()), profiles).CloneNative(),
@@ -437,26 +440,27 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 			}
 
 			if len(filteredCandidateMembers) == 0 {
-				return response.InternalError(fmt.Errorf("Couldn't find a cluster member for the instance"))
+				return response.InternalError(errors.New("Couldn't find a cluster member for the instance"))
 			}
 
 			targetMemberInfo = &filteredCandidateMembers[0]
 		}
 
 		if targetMemberInfo.IsOffline(s.GlobalConfig.OfflineThreshold()) {
-			return response.BadRequest(fmt.Errorf("Target cluster member is offline"))
+			return response.BadRequest(errors.New("Target cluster member is offline"))
 		}
 	}
 
 	// If the user requested a specific server group, make sure we can have it recorded.
 	var targetGroupName string
-	if strings.HasPrefix(target, targetGroupPrefix) {
-		targetGroupName = strings.TrimPrefix(target, targetGroupPrefix)
+	after, ok := strings.CutPrefix(target, targetGroupPrefix)
+	if ok {
+		targetGroupName = after
 	}
 
 	// Check that we're not requested to move to the same location we're currently on.
 	if target != "" && targetMemberInfo.Name == inst.Location() {
-		return response.BadRequest(fmt.Errorf("Requested target server is the same as current server"))
+		return response.BadRequest(errors.New("Requested target server is the same as current server"))
 	}
 
 	// If the instance needs to move, make sure it doesn't have backups.
@@ -473,7 +477,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 		}
 
 		if len(backups) > 0 {
-			return response.BadRequest(fmt.Errorf("Instances with backups cannot be moved"))
+			return response.BadRequest(errors.New("Instances with backups cannot be moved"))
 		}
 	}
 
@@ -509,7 +513,7 @@ func instancePost(d *Daemon, r *http.Request) response.Response {
 	resources := map[string][]api.URL{}
 	resources["instances"] = []api.URL{*api.NewURL().Path(version.APIVersion, "instances", name)}
 	run := func(op *operations.Operation) error {
-		return ws.Do(s, op)
+		return ws.do(op)
 	}
 
 	cancel := func(op *operations.Operation) error {
@@ -546,7 +550,7 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 
 	// Check that we're not requested to move to the same storage pool we're currently use.
 	if req.Pool != "" && req.Pool == sourcePool.Name() {
-		return fmt.Errorf("Requested storage pool is the same as current pool")
+		return errors.New("Requested storage pool is the same as current pool")
 	}
 
 	// Get the DB volume type for the instance.
@@ -575,10 +579,6 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 			return fmt.Errorf("Failed to relink instance database data: %w", err)
 		}
 
-		if err != nil {
-			return fmt.Errorf("Failed creating mount point of instance on target node: %w", err)
-		}
-
 		// Import the instance into the storage.
 		_, err = sourcePool.ImportInstance(inst, nil, nil)
 		if err != nil {
@@ -620,14 +620,15 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 	}
 
 	// Apply the config overrides.
-	for k, v := range req.Config {
-		targetInstInfo.Config[k] = v
+	maps.Copy(targetInstInfo.Config, req.Config)
+
+	// If "security.secureboot" has changed, force a NVRAM reset.
+	if util.IsTrueOrEmpty(inst.ExpandedConfig()["security.secureboot"]) != util.IsTrueOrEmpty(req.Config["security.secureboot"]) {
+		targetInstInfo.Config["volatile.apply_nvram"] = "true"
 	}
 
 	// Apply the device overrides.
-	for k, v := range req.Devices {
-		targetInstInfo.Devices[k] = v
-	}
+	maps.Copy(targetInstInfo.Devices, req.Devices)
 
 	// Apply the profile overrides.
 	if req.Profiles != nil {
@@ -636,6 +637,15 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 
 	// Handle storage pool override.
 	if req.Pool != "" {
+		err := s.DB.Cluster.Transaction(ctx, func(ctx context.Context, tx *db.ClusterTx) error {
+			_, err := tx.GetStoragePoolID(ctx, req.Pool)
+
+			return err
+		})
+		if response.IsNotFoundError(err) {
+			return fmt.Errorf("Can't find a storage pool '%s' for the instance to use", req.Pool)
+		}
+
 		rootDevKey, rootDev, err := internalInstance.GetRootDiskDevice(inst.ExpandedDevices().CloneNative())
 		if err != nil {
 			return err
@@ -767,6 +777,14 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 			}
 		}
 
+		// Connect the event handler.
+		_, err = target.GetEvents()
+		if err != nil {
+			return err
+		}
+
+		defer target.Disconnect()
+
 		// Create the target instance.
 		destOp, err := target.CreateInstance(api.InstancesPost{
 			Name:        targetInstName,
@@ -839,9 +857,7 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 		}
 
 		target = target.UseProject(inst.Project().Name)
-		if targetMemberInfo != nil {
-			target = target.UseTarget(targetMemberInfo.Name)
-		}
+		target = target.UseTarget(targetMemberInfo.Name)
 
 		// Get the source member info if missing.
 		if sourceMemberInfo == nil {
@@ -872,8 +888,8 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 			return fmt.Errorf("Failed setting up instance migration on source: %w", err)
 		}
 
-		run := func(op *operations.Operation) error {
-			return sourceMigration.Do(s, op)
+		run := func(_ *operations.Operation) error {
+			return sourceMigration.do(op)
 		}
 
 		cancel := func(op *operations.Operation) error {
@@ -902,6 +918,14 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 			sourceSecrets[connName] = conn.Secret()
 		}
 
+		// Connect the event handler.
+		_, err = target.GetEvents()
+		if err != nil {
+			return err
+		}
+
+		defer target.Disconnect()
+
 		// Create the target instance.
 		destOp, err := target.CreateInstance(api.InstancesPost{
 			Name:        inst.Name(),
@@ -966,6 +990,27 @@ func migrateInstance(ctx context.Context, s *state.State, inst instance.Instance
 				if err != nil {
 					return fmt.Errorf("Failed to set volatile.apply_template config key: %w", err)
 				}
+			} else if targetMemberInfo != nil {
+				config, err := dbCluster.GetInstanceConfig(ctx, tx.Tx(), inst.ID())
+				if err != nil {
+					return err
+				}
+
+				// Remove 'volatile.cluster.group' if the instance is on a node outside the specified cluster group.
+				group := config["volatile.cluster.group"]
+				if group != "" {
+					groupMembers, err := tx.GetClusterGroupNodes(ctx, group)
+					if err != nil {
+						return err
+					}
+
+					if !slices.Contains(groupMembers, targetMemberInfo.Name) {
+						err = tx.DeleteInstanceConfigKey(ctx, id, "volatile.cluster.group")
+						if err != nil {
+							return fmt.Errorf("Failed to remove volatile.cluster.group config key: %w", err)
+						}
+					}
+				}
 			}
 
 			// Restore the original value of "volatile.apply_template".
