@@ -503,6 +503,11 @@ func createFromCopy(ctx context.Context, s *state.State, r *http.Request, projec
 		return response.SmartError(err)
 	}
 
+	// If "security.secureboot" has changed, force a NVRAM reset.
+	if util.IsTrueOrEmpty(source.ExpandedConfig()["security.secureboot"]) != util.IsTrueOrEmpty(req.Config["security.secureboot"]) {
+		req.Config["volatile.apply_nvram"] = "true"
+	}
+
 	// When clustered, use the node name, otherwise use the hostname.
 	if s.ServerClustered {
 		serverName := s.ServerName
@@ -997,7 +1002,7 @@ func instancesPost(d *Daemon, r *http.Request) response.Response {
 			}
 
 			opAPI := op.Get()
-			return operations.ForwardedOperationResponse(targetProjectName, &opAPI)
+			return operations.ForwardedOperationResponse(&opAPI)
 		}
 
 		if err == nil {
@@ -1291,7 +1296,7 @@ func instancesPost(d *Daemon, r *http.Request) response.Response {
 		}
 
 		opAPI := op.Get()
-		return operations.ForwardedOperationResponse(targetProjectName, &opAPI)
+		return operations.ForwardedOperationResponse(&opAPI)
 	}
 
 	switch req.Source.Type {
