@@ -34,6 +34,7 @@ import (
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/validate"
 )
 
 var storagePoolVolumeSnapshotsTypeCmd = APIEndpoint{
@@ -205,7 +206,7 @@ func storagePoolVolumeSnapshotsTypePost(d *Daemon, r *http.Request) response.Res
 		pattern = "snap%d"
 	}
 
-	pattern, err = internalUtil.RenderTemplate(pattern, pongo2.Context{
+	renderedPattern, err := internalUtil.RenderTemplate(pattern, pongo2.Context{
 		"creation_date": time.Now(),
 	})
 	if err != nil {
@@ -213,17 +214,19 @@ func storagePoolVolumeSnapshotsTypePost(d *Daemon, r *http.Request) response.Res
 	}
 
 	// Get a snapshot name.
-	if req.Name == "" {
+	if req.Name == "" && strings.Count(renderedPattern, "%d") == 1 {
 		var i int
 
 		_ = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
-			i = tx.GetNextStorageVolumeSnapshotIndex(ctx, poolName, volumeName, volumeType, pattern)
+			i = tx.GetNextStorageVolumeSnapshotIndex(ctx, poolName, volumeName, volumeType, renderedPattern)
 
 			return nil
 		})
 
-		req.Name = fmt.Sprintf(pattern, i)
-	} else {
+		req.Name = fmt.Sprintf(renderedPattern, i)
+	} else if req.Name == "" && renderedPattern != pattern {
+		req.Name = renderedPattern
+	} else if req.Name != "" {
 		// Make sure the snapshot doesn't already exist.
 		err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 			snapDBVolume, err := tx.GetStoragePoolVolume(ctx, pool.ID(), projectName, volumeType, fmt.Sprintf("%s/%s", volumeName, req.Name), true)
@@ -238,12 +241,14 @@ func storagePoolVolumeSnapshotsTypePost(d *Daemon, r *http.Request) response.Res
 		if err != nil {
 			return response.SmartError(err)
 		}
+	} else {
+		return response.BadRequest(errors.New("Couldn't determine snapshot name"))
 	}
 
-	// Validate the snapshot name using same rule as pool name.
-	err = pool.ValidateName(req.Name)
+	// Quick checks.
+	err = validate.IsAPIName(req.Name, false)
 	if err != nil {
-		return response.BadRequest(err)
+		return response.BadRequest(fmt.Errorf("Invalid storage volume snapshot name: %w", err))
 	}
 
 	// Fill in the expiry.
@@ -603,12 +608,9 @@ func storagePoolVolumeSnapshotTypePost(d *Daemon, r *http.Request) response.Resp
 	}
 
 	// Quick checks.
-	if req.Name == "" {
-		return response.BadRequest(errors.New("No name provided"))
-	}
-
-	if strings.Contains(req.Name, "/") {
-		return response.BadRequest(errors.New("Storage volume names may not contain slashes"))
+	err = validate.IsAPIName(req.Name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid storage volume snapshot name: %w", err))
 	}
 
 	// This is a migration request so send back requested secrets.
@@ -1571,7 +1573,7 @@ func volumeDetermineNextSnapshotName(ctx context.Context, s *state.State, volume
 		}
 	}
 
-	if snapshotExists {
+	if snapshotExists && count == 1 {
 		var i int
 
 		_ = s.DB.Cluster.Transaction(ctx, func(ctx context.Context, tx *db.ClusterTx) error {
@@ -1581,6 +1583,8 @@ func volumeDetermineNextSnapshotName(ctx context.Context, s *state.State, volume
 		})
 
 		return strings.Replace(pattern, "%d", strconv.Itoa(i), 1), nil
+	} else if snapshotExists {
+		return "", errors.New("Snapshot with that name already exists")
 	}
 
 	return pattern, nil
