@@ -2,8 +2,8 @@ package main
 
 import (
 	"encoding/json"
+	"errors"
 	"fmt"
-	"os"
 	"runtime"
 	"slices"
 	"strconv"
@@ -13,9 +13,9 @@ import (
 	"github.com/spf13/cobra"
 
 	incus "github.com/lxc/incus/v6/client"
-	cli "github.com/lxc/incus/v6/internal/cmd"
 	"github.com/lxc/incus/v6/internal/i18n"
 	"github.com/lxc/incus/v6/shared/api"
+	cli "github.com/lxc/incus/v6/shared/cmd"
 	"github.com/lxc/incus/v6/shared/osarch"
 	"github.com/lxc/incus/v6/shared/util"
 )
@@ -62,8 +62,7 @@ func (c *cmdMigrate) Command() *cobra.Command {
 
 func (c *cmdMigrate) RunE(cmd *cobra.Command, args []string) error {
 	if (len(c.flagContainers) == 0 && !c.flagAll) || (len(c.flagContainers) > 0 && c.flagAll) {
-		fmt.Fprintln(os.Stderr, "You must either pass container names or --all")
-		os.Exit(1)
+		return errors.New("You must either pass container names or --all")
 	}
 
 	// Connect to the daemon
@@ -106,7 +105,7 @@ func validateConfig(conf []string, container *liblxc.Container) error {
 	// Checking whether container has already been migrated
 	fmt.Println("Checking whether container has already been migrated")
 	if len(getConfig(conf, "incus.migrated")) > 0 {
-		return fmt.Errorf("Container has already been migrated")
+		return errors.New("Container has already been migrated")
 	}
 
 	// Validate lxc.utsname / lxc.uts.name
@@ -116,7 +115,7 @@ func validateConfig(conf []string, container *liblxc.Container) error {
 	}
 
 	if value == nil || value[0] != container.Name() {
-		return fmt.Errorf("Container name doesn't match lxc.uts.name / lxc.utsname")
+		return errors.New("Container name doesn't match lxc.uts.name / lxc.utsname")
 	}
 
 	// Validate lxc.aa_allow_incomplete: must be set to 0 or unset.
@@ -133,7 +132,7 @@ func validateConfig(conf []string, container *liblxc.Container) error {
 		}
 
 		if v != 0 {
-			return fmt.Errorf("Container allows incomplete AppArmor support")
+			return errors.New("Container allows incomplete AppArmor support")
 		}
 	}
 
@@ -147,7 +146,7 @@ func validateConfig(conf []string, container *liblxc.Container) error {
 		}
 
 		if v != 1 {
-			return fmt.Errorf("Container doesn't mount a minimal /dev filesystem")
+			return errors.New("Container doesn't mount a minimal /dev filesystem")
 		}
 	}
 
@@ -168,7 +167,7 @@ func validateConfig(conf []string, container *liblxc.Container) error {
 func convertContainer(d incus.InstanceServer, container *liblxc.Container, storage string, dryRun bool, rsyncArgs string, debug bool) error {
 	// Don't migrate running containers
 	if container.Running() {
-		return fmt.Errorf("Only stopped containers can be migrated")
+		return errors.New("Only stopped containers can be migrated")
 	}
 
 	fmt.Println("Parsing LXC configuration")
@@ -207,7 +206,7 @@ func convertContainer(d incus.InstanceServer, container *liblxc.Container, stora
 		}
 	}
 	if found {
-		return fmt.Errorf("Container already exists")
+		return errors.New("Container already exists")
 	}
 
 	// Validate config
@@ -316,7 +315,7 @@ func convertContainer(d incus.InstanceServer, container *liblxc.Container, stora
 	}
 
 	if value != nil && value[0] != "/usr/share/lxc/config/common.seccomp" {
-		return fmt.Errorf("Custom seccomp profiles aren't supported")
+		return errors.New("Custom seccomp profiles aren't supported")
 	}
 
 	// Convert SELinux
@@ -327,7 +326,7 @@ func convertContainer(d incus.InstanceServer, container *liblxc.Container, stora
 	}
 
 	if value != nil {
-		return fmt.Errorf("Custom SELinux policies aren't supported")
+		return errors.New("Custom SELinux policies aren't supported")
 	}
 
 	// Convert capabilities
@@ -340,13 +339,13 @@ func convertContainer(d incus.InstanceServer, container *liblxc.Container, stora
 				continue
 			}
 
-			return fmt.Errorf("Custom capabilities aren't supported")
+			return errors.New("Custom capabilities aren't supported")
 		}
 	}
 
 	value = getConfig(conf, "lxc.cap.keep")
 	if value != nil {
-		return fmt.Errorf("Custom capabilities aren't supported")
+		return errors.New("Custom capabilities aren't supported")
 	}
 
 	// Add rest of the keys to lxc.raw
@@ -399,14 +398,14 @@ func convertContainer(d incus.InstanceServer, container *liblxc.Container, stora
 		arch = value[0]
 	}
 
-	archID, err := osarch.ArchitectureId(arch)
+	archID, err := osarch.ArchitectureID(arch)
 	if err != nil {
 		// If arch is linux32 or linux64, the architecture ID cannot be determined as multiple
 		// architectures have the linux32 or linux64 personality. In this case, assume the native
 		// architecture.
 		arch = runtime.GOARCH
 
-		archID, err = osarch.ArchitectureId(arch)
+		archID, err = osarch.ArchitectureID(arch)
 		if err != nil {
 			return err
 		}
@@ -586,13 +585,13 @@ func convertStorageConfig(conf []string, devices map[string]map[string]string) e
 		if slices.Contains(strings.Split(parts[3], ","), "optional") {
 			device["optional"] = "true"
 		} else {
-			if strings.HasPrefix(parts[0], "/") {
-				if !util.PathExists(parts[0]) {
-					return fmt.Errorf("Invalid path: %s", parts[0])
-				}
-			} else {
+			if !strings.HasPrefix(parts[0], "/") {
 				continue
 			}
+
+			if !util.PathExists(parts[0]) {
+				return fmt.Errorf("Invalid path: %s", parts[0])
+			}
 		}
 
 		// Set the source
@@ -622,7 +621,7 @@ func getRootfs(conf []string) (string, error) {
 	if value == nil {
 		value = getConfig(conf, "lxc.rootfs")
 		if value == nil {
-			return "", fmt.Errorf("Invalid container, missing lxc.rootfs key")
+			return "", errors.New("Invalid container, missing lxc.rootfs key")
 		}
 	}
 
