@@ -18,6 +18,7 @@ type UnixHotplugEvent struct {
 
 	Vendor  string
 	Product string
+	PCI     string
 
 	Path        string
 	Major       uint32
@@ -94,7 +95,7 @@ func UnixHotplugRunHandlers(state *state.State, event *UnixHotplugEvent) {
 }
 
 // UnixHotplugNewEvent instantiates a new UnixHotplugEvent struct.
-func UnixHotplugNewEvent(action string, vendor string, product string, major string, minor string, subsystem string, devname string, ueventParts []string, ueventLen int) (UnixHotplugEvent, error) {
+func UnixHotplugNewEvent(action string, vendor string, product string, pci string, major string, minor string, subsystem string, devname string, ueventParts []string, ueventLen int) (UnixHotplugEvent, error) {
 	majorInt, err := strconv.ParseUint(major, 10, 32)
 	if err != nil {
 		return UnixHotplugEvent{}, err
@@ -109,6 +110,7 @@ func UnixHotplugNewEvent(action string, vendor string, product string, major str
 		action,
 		vendor,
 		product,
+		pci,
 		devname,
 		uint32(majorInt),
 		uint32(minorInt),
