@@ -74,6 +74,11 @@ const DiskIOUring = "io_uring"
 // DiskLoopBacked is used to indicate disk is backed onto a loop device.
 const DiskLoopBacked = "loop"
 
+// IsSpecialDisk checks whether the provided source is a special disk.
+func IsSpecialDisk(source string) bool {
+	return slices.Contains([]string{diskSourceCloudInit, diskSourceAgent, diskSourceTmpfs, diskSourceTmpfsOverlay}, source)
+}
+
 type diskBlockLimit struct {
 	readBps   int64
 	readIops  int64
@@ -118,7 +123,7 @@ func (d *disk) CanMigrate() bool {
 	}
 
 	// Virtual disks are migratable.
-	if slices.Contains([]string{diskSourceCloudInit, diskSourceAgent, diskSourceTmpfs, diskSourceTmpfsOverlay}, d.config["source"]) {
+	if IsSpecialDisk(d.config["source"]) {
 		return true
 	}
 
@@ -1444,6 +1449,7 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 			// be returned as the path to the block device).
 			if d.config["pool"] != "" {
 				var revertFunc func()
+				var mountInfo *storagePools.MountInfo
 
 				// Derive the effective storage project name from the instance config's project.
 				storageProjectName, err := project.StorageVolumeProject(d.state.DB.Cluster, d.inst.Project().Name, db.StoragePoolVolumeTypeCustom)
@@ -1510,7 +1516,7 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 					return &runConf, nil
 				}
 
-				revertFunc, mount.DevPath, _, err = d.mountPoolVolume()
+				revertFunc, mount.DevPath, mountInfo, err = d.mountPoolVolume()
 				if err != nil {
 					return nil, diskSourceNotFoundError{msg: "Failed mounting volume", err: err}
 				}
@@ -1518,6 +1524,7 @@ func (d *disk) startVM() (*deviceConfig.RunConfig, error) {
 				reverter.Add(revertFunc)
 
 				mount.Opts = append(mount.Opts, d.detectVMPoolMountOpts()...)
+				mount.BackingPath = append(mount.BackingPath, mountInfo.BackingPath...)
 			}
 
 			if util.IsTrue(d.config["readonly"]) {
