@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"net/http"
+	"net/url"
 	"path/filepath"
 	"slices"
 	"strconv"
@@ -49,6 +50,33 @@ func HiddenStoragePools(ctx context.Context, tx *db.ClusterTx, projectName strin
 	return hiddenPools, nil
 }
 
+// AllowImageDownload returns an error if any project-specific restriction is violated when downloading a new image.
+func AllowImageDownload(tx *db.ClusterTx, projectName string, uri string) error {
+	info, err := fetchProject(tx, projectName, true)
+	if err != nil {
+		return err
+	}
+
+	if info == nil {
+		return nil
+	}
+
+	// Check if we have image server restrictions.
+	if util.IsTrue(info.Project.Config["restricted"]) && info.Project.Config["restricted.images.servers"] != "" {
+		u, err := url.Parse(uri)
+		if err != nil {
+			return err
+		}
+
+		servers := util.SplitNTrimSpace(info.Project.Config["restricted.images.servers"], ",", -1, false)
+		if !slices.Contains(servers, u.Host) {
+			return fmt.Errorf("Image server %q isn't allowed in this project", u.Host)
+		}
+	}
+
+	return nil
+}
+
 // AllowInstanceCreation returns an error if any project-specific limit or
 // restriction is violated when creating a new instance.
 func AllowInstanceCreation(tx *db.ClusterTx, projectName string, req api.InstancesPost) error {
@@ -75,6 +103,26 @@ func AllowInstanceCreation(tx *db.ClusterTx, projectName string, req api.Instanc
 		req.Profiles = []string{"default"}
 	}
 
+	if util.IsTrue(info.Project.Config["restricted"]) {
+		// Restricted projects aren't allowed to use pull migration.
+		if req.Source.Type == "migration" && req.Source.Mode == "pull" {
+			return errors.New("Restricted projects aren't allowed to use pull mode migration")
+		}
+
+		// Check if we have image server restrictions.
+		if req.Source.Type == "image" && info.Project.Config["restricted.images.servers"] != "" {
+			u, err := url.Parse(req.Source.Server)
+			if err != nil {
+				return err
+			}
+
+			servers := util.SplitNTrimSpace(info.Project.Config["restricted.images.servers"], ",", -1, false)
+			if !slices.Contains(servers, u.Host) {
+				return fmt.Errorf("Image server %q isn't allowed in this project", u.Host)
+			}
+		}
+	}
+
 	err = checkInstanceCountLimit(info, instanceType)
 	if err != nil {
 		return err
@@ -265,6 +313,11 @@ func AllowVolumeCreation(tx *db.ClusterTx, projectName string, poolName string,
 		return nil
 	}
 
+	// Restricted projects aren't allowed to use pull migration.
+	if util.IsTrue(info.Project.Config["restricted"]) && req.Source.Type == "migration" && req.Source.Mode == "pull" {
+		return errors.New("Restricted projects aren't allowed to use pull mode migration")
+	}
+
 	// If "limits.disk" is not set, there's nothing to do.
 	if info.Project.Config["limits.disk"] == "" {
 		return nil
@@ -857,6 +910,7 @@ var allRestrictions = map[string]string{
 	"restricted.devices.disk.paths":        "",
 	"restricted.idmap.uid":                 "",
 	"restricted.idmap.gid":                 "",
+	"restricted.images.servers":            "",
 	"restricted.networks.access":           "",
 	"restricted.snapshots":                 "block",
 }
@@ -878,6 +932,10 @@ func isContainerLowLevelOptionForbidden(key string) bool {
 		return true
 	}
 
+	if strings.HasPrefix(key, "security.bpffs") {
+		return true
+	}
+
 	if slices.Contains([]string{
 		"boot.host_shutdown_action",
 		"boot.host_shutdown_timeout",
