@@ -358,6 +358,30 @@ test_container_devices_nic_p2p() {
     # Test hotplugging nic with new name (rather than updating existing nic).
     incus config device add "${ctName}" eth1 nic nictype=p2p
 
+    incus config device remove "${ctName}" eth1
+
+    # Test attached and connected keys.
+    incus config device add "${ctName}" eth0 nic nictype=p2p name=eth0
+    incus exec "${ctName}" ip link set eth0 up
+    [ "$(incus file pull "${ctName}/sys/class/net/eth0/operstate" -)" = "up" ]
+    incus config device set "${ctName}" eth0 connected=false
+    incus exec "${ctName}" ip link set eth0 up
+    [ "$(incus file pull "${ctName}/sys/class/net/eth0/operstate" -)" = "down" ]
+    incus config device set "${ctName}" eth0 attached=false
+    ! incus file pull "${ctName}/sys/class/net/eth0/operstate" - || false
+    incus config device set "${ctName}" eth0 connected=true
+    ! incus file pull "${ctName}/sys/class/net/eth0/operstate" - || false
+    incus config device set "${ctName}" eth0 attached=true
+    incus exec "${ctName}" ip link set eth0 up
+    [ "$(incus file pull "${ctName}/sys/class/net/eth0/operstate" -)" = "up" ]
+    incus config device set "${ctName}" eth0 connected=false
+    incus exec "${ctName}" ip link set eth0 up
+    [ "$(incus file pull "${ctName}/sys/class/net/eth0/operstate" -)" = "down" ]
+    # Check that it survives a reboot.
+    incus restart "${ctName}"
+    incus exec "${ctName}" ip link set eth0 up
+    [ "$(incus file pull "${ctName}/sys/class/net/eth0/operstate" -)" = "down" ]
+
     incus stop -f "${ctName}"
 
     # Check we haven't left any NICS lying around.
